@@ -1,4 +1,4 @@
-# $Id: HTTP.pm 334 2008-07-13 08:07:22Z rcaputo $
+# $Id: HTTP.pm 341 2008-11-24 22:32:18Z rcaputo $
 
 package POE::Component::Client::HTTP;
 
@@ -11,7 +11,7 @@ use constant DEBUG      => 0;
 use constant DEBUG_DATA => 0;
 
 use vars qw($VERSION);
-$VERSION = '0.85';
+$VERSION = '0.86';
 
 use Carp qw(croak);
 use HTTP::Response;
@@ -982,7 +982,7 @@ POE::Component::Client::HTTP - a HTTP user-agent component
     Timeout   => 60,                    # defaults to 180 seconds
     MaxSize   => 16384,                 # defaults to entire response
     Streaming => 4096,                  # defaults to 0 (off)
-    FollowRedirects => 2                # defaults to 0 (off)
+    FollowRedirects => 2,               # defaults to 0 (off)
     Proxy     => "http://localhost:80", # defaults to HTTP_PROXY env. variable
     NoProxy   => [ "localhost", "127.0.0.1" ], # defs to NO_PROXY env. variable
     BindAddr  => "12.34.56.78",         # defaults to INADDR_ANY
